import React from 'react';
import { ProForm, ProFormText, ProFormDigit, ProFormSelect } from '@ant-design/pro-components';
import { Form, Button } from 'antd';
import Curd from '@/components/Page/Curd';
import Wangeditor from '@/components/Wangeditor';
import { UploadImage } from '@/components/Upload';
import {
  getTaNotice,
  getTaNoticeById,
  postTaNotice,
  putTaNotice,
  deleteTaNotice,
} from '@/service/tanotice';

const request = {
  list: getTaNotice,
  save: postTaNotice,
  update: putTaNotice,
  del: deleteTaNotice,
}

export default (props) => {
  const tableRef = React.useRef();

  const onStatusChange = (row) => {
    tableRef.current.showLoading('正在操作, 请稍候...');
    putTaNotice(row.noticeId, {
      ...row,
      status: Math.abs(0 - row.status),
    }).then(() => {
      tableRef.current.hideLoading();
      tableRef.current.reload();
    }).catch(() => {
      tableRef.current.hideLoading();
    });
  }

  const columns = React.useMemo(() => [
    {
      title: "日期",
      dataIndex: "createDate",
      valueType: 'date',
      hideInSearch: true,
    },
    {
      title: "标题",
      dataIndex: "title",
    },
    {
      title: "图片",
      dataIndex: "thumb",
      hideInSearch: true,
      render: t => !t || t.length < 3 ? null : <img src={t} alt="" style={{width: '64px', height: '64px'}} />,
    },
    {
      title: "状态",
      dataIndex: "status",
      valueEnum: {
        0: {
          text: "未发布",
          status: "Default",
        },
        1: {
          text: "已发布",
          status: "Success",
        },
      },
    },
  ], []);

  const optionRender = React.useCallback((_, record) => {
    return [
      <Button style={{ padding: 0 }} type="link" key="pub" onClick={() => onStatusChange(record) }>
        {record.status == 1 ? '取消发布' : '发布'}
      </Button>
    ]
  }, []);

  return (
    <Curd
      rowKey="noticeId"
      tableRef={tableRef}
      columns={columns}
      request={request}
      optionRender={optionRender}
      renderFormItems={() => (
        <>
          <ProFormText
            label="标题"
            name="title"
            rules={[
              { required: true, message: '请输入标题' },
            ]}
          />
          <Form.Item label="图片" name="thumb">
            <UploadImage />
          </Form.Item>
          <Form.Item label="正文" name="content">
            <Wangeditor
              toolbarConfig={{
                toolbarKeys: [
                  'headerSelect',
                  'blockquote',
                  '|',
                  'bold',
                  'underline',
                  'italic',
                  'color',
                  'fontSize',
                  '|',
                  'bulletedList',
                  'numberedList',
                ]
              }}
            />
          </Form.Item>
          <ProForm.Group>
            <ProFormDigit
              label="权重"
              name="weight"
              min={1}
              fieldProps={{ precision: 0 }}
            />
            <ProFormSelect
              label="状态"
              name="status"
              options={[
                {label: '未发布', value: 0},
                {label: '发布', value: 1},
              ]}
            />
          </ProForm.Group>
        </>
      )}
    />
  )
}
